@@ -1,13 +1,15 @@
 import hashlib
-import os
+from pathlib import Path
 from typing import Iterator
 
-from ..fs import files_in_recursively, link
+from ..fs import HOME, link
 from ..utils import *
 from .manual_version import ManualVersion
 
 
 class Links(ManualVersion):
+    dest: Path
+
     def __init__(
         self,
         links: str,
@@ -19,13 +21,14 @@ class Links(ManualVersion):
         **kwargs,
     ) -> None:
         self.root = root
-        self.source = os.path.abspath(links)
-        if not dest.startswith("/"):
+        self.source = Path(links).absolute()
+        if dest.startswith("/"):
+            self.dest = Path(dest)
+        else:
             if self.root:
-                dest = os.path.join(with_os(linux="/root", macos="/var/root"), dest)
+                self.dest = Path("~root").expanduser() / dest
             else:
-                dest = os.path.join(home(), dest)
-        self.dest = dest
+                self.dest = HOME / dest
         self.dot = dot
         self.shallow = shallow
         self.only = unsome_(only)
@@ -35,34 +38,36 @@ class Links(ManualVersion):
     def name(self) -> str:
         return f"links-{self.source}-{self.dest}"
 
-    def all_paths(self) -> Iterator[str]:
+    def all_paths(self) -> Iterator[Path]:
         if self.shallow:
-            for entry in os.scandir(self.source):
-                yield entry.path
+            candidates = self.source.glob("*")
         else:
-            for path in files_in_recursively(self.source):
-                if os.path.isfile(path):
-                    yield path
+            candidates = self.source.rglob("*")
 
-    def paths(self) -> Iterator[str]:
+        for path in candidates:
+            if path.is_file():
+                yield path
+
+    def paths(self) -> Iterator[Path]:
         for path in self.all_paths():
-            if self.only and os.path.basename(path) not in self.only:
+            if self.only and path.name not in self.only:
                 continue
             yield path
 
     def get_remote_version(self) -> str:
         m = hashlib.sha256()
         for path in self.paths():
-            m.update(path.encode())
+            m.update(str(path).encode())
         return m.hexdigest()
 
     def install(self) -> None:
         # TODO: remove links that were created before but no longer exist
         for path in self.paths():
-            target = os.path.relpath(path, self.source)
+            target = path.relative_to(self.source)
             if self.dot:
-                target = "." + target
-            target = os.path.join(self.dest, target)
+                first_part, *parts = target.parts
+                target = Path("." + first_part, *parts)
+            target = self.dest.joinpath(target)
 
             link(path, target, sudo=self.root)
         super().install()
